@@ -8,13 +8,13 @@ from moonshot.src.datasets.dataset_arguments import (
 
 
 class CSV_Dataset_DTO(DatasetPydanticModel):
-    id: Optional[str] = None  # Not a required from user
-    examples: Optional[Any] = None  # Not a required from user
+    id: Optional[str] = None  # Not required from user
+    examples: Optional[Any] = None  # Not required from user
     name: str = Field(..., min_length=1)
     description: str = Field(default="", min_length=1)
     license: Optional[str] = ""
     reference: Optional[str] = ""
-    csv_file_path: str = Field(..., min_length=1)
+    file_path: str = Field(..., min_length=1)
 
 
 class HF_Dataset_DTO(DatasetPydanticModel):
