@@ -649,7 +649,7 @@ class RedTeamingPromptArguments(BaseModel):
 
         This method collects all the attributes of the RedTeamingPromptArguments instance and forms a tuple
         with the attribute values in this specific order: conn_id, cs_id, pt_id, am_id, me_id, original_prompt,
-        connector_prompt.prompt, system_prompt, connector_prompt.predicted_results.response, 
+        connector_prompt.prompt, system_prompt, connector_prompt.predicted_results.response,
         connector_prompt.duration, start_time.
 
         Returns:
@@ -664,7 +664,9 @@ class RedTeamingPromptArguments(BaseModel):
             self.original_prompt,
             self.connector_prompt.prompt,
             self.system_prompt,
-            self.connector_prompt.predicted_results.response if self.connector_prompt.predicted_results else "",
+            self.connector_prompt.predicted_results.response
+            if self.connector_prompt.predicted_results
+            else "",
             str(self.connector_prompt.duration),
             self.start_time,
         )
@@ -689,7 +691,11 @@ class RedTeamingPromptArguments(BaseModel):
             "original_prompt": self.original_prompt,
             "prepared_prompt": self.connector_prompt.prompt,
             "system_prompt": self.system_prompt,
-            "response": self.connector_prompt.predicted_results.response if self.connector_prompt.predicted_results else "",
+            "response": (
+                self.connector_prompt.predicted_results.response
+                if self.connector_prompt.predicted_results
+                else ""
+            ),
             "duration": str(self.connector_prompt.duration),
             "start_time": self.start_time,
         }
